@@ -6,6 +6,8 @@ import (
 	"regexp"
 	"strings"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	"github.com/AlecAivazis/survey/v2"
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
@@ -22,19 +24,22 @@ func NewCmdUpdate(f cmdutils.Factory) *cobra.Command {
 		Short: `Update a merge request.`,
 		Long:  ``,
 		Example: heredoc.Doc(`
-			Mark a merge request as ready
-			- glab mr update 23 --ready
+		# Mark a merge request as ready
+		$ glab mr update 23 --ready
 
-			Mark a merge request as draft
-			- glab mr update 23 --draft
+		# Mark a merge request as draft
+		$ glab mr update 23 --draft
 
-			Updates the merge request for the current branch
-			- glab mr update --draft
+		# Updates the merge request for the current branch
+		$ glab mr update --draft
 
-			Update merge request with commit information
-			- glab mr update 23 --fill --fill-commit-body --yes
+		# Update merge request with commit information
+		$ glab mr update 23 --fill --fill-commit-body --yes
 		`),
 		Args: cobra.MaximumNArgs(1),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 			var actions []string
